.. title:: Table of Contents

Welcome to the documentation of pypoman, a PYthon module for POlyhedral
MANipulations.

Chebyshev center
================

.. autofunction:: pypoman.polyhedron.compute_chebyshev_center

Duality
=======

.. automodule:: pypoman.duality
    :members:

Intersection
============

.. automodule:: pypoman.intersection
    :members:

Linear programming
==================

.. autofunction:: pypoman.lp.solve_lp

Polygon manipulation
====================

.. automodule:: pypoman.polygon
    :members:

Projection
==========

.. automodule:: pypoman.projection
    :members:

References
==========

.. [Boyd04] `Convex Optimization
   <https://web.stanford.edu/~boyd/cvxbook/bv_cvxbook.pdf>`_, Stephen Boyd and
   Lieven Vandenberghe, Cambridge University Press, 2004.

.. [Bretl08] *Testing Static Equilibrium for Legged Robots*, T. Bretl and S.
   Lall, IEEE Transactions on Robotics, vol. 24, no. 4, pp. 794-807, August
   2008.
